import { Component, NgModule } from '@angular/core';
import { ToastController, LoadingController, IonicModule } from '@ionic/angular';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { Router, RouterModule } from '@angular/router';
import { __awaiter } from 'tslib';
import { delay } from 'bluebird';
import { EdgeCentralClient } from '@sirusdev/ec-client-angular';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/login.page.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LoginPage {
    /**
     * @param {?} toast
     * @param {?} loading
     * @param {?} router
     * @param {?} ec
     */
    constructor(toast, loading, router, ec) {
        this.toast = toast;
        this.loading = loading;
        this.router = router;
        this.ec = ec;
        this.tab = 'device';
    }
    /**
     * @param {?} event
     * @return {?}
     */
    tabChanged(event) {
        this.tab = event.detail.value;
    }
    /**
     * @param {?} form
     * @return {?}
     */
    loginDevice(form) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!form.valid) {
                return;
            }
            /** @type {?} */
            const loading = yield this.loading.create({
                message: 'Menghubungkan...'
            });
            yield loading.present();
            try {
                yield this.ec.loginByDevice(this.deviceID);
                // wait local storage to persist
                yield delay(500);
                window.location.replace('/');
            }
            catch (err) {
                /** @type {?} */
                const toast = yield this.toast.create({
                    message: err.message || err.toString(),
                    color: 'danger',
                    duration: 5000
                });
                yield toast.present();
            }
            yield loading.dismiss();
        });
    }
    /**
     * @return {?}
     */
    loginProvider() {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const loading = yield this.loading.create({
                message: 'Menghubungkan...'
            });
            yield loading.present();
            try {
                yield this.ec.loginByProvider(this.providerID, this.password);
                // wait local storage to persist
                yield delay(500);
                window.location.replace('/');
            }
            catch (err) {
                /** @type {?} */
                const toast = yield this.toast.create({
                    message: err.message || err.toString(),
                    color: 'danger',
                    duration: 5000
                });
                yield toast.present();
            }
            yield loading.dismiss();
        });
    }
}
LoginPage.decorators = [
    { type: Component, args: [{
                selector: 'qh-login-page',
                template: "<ion-header translucent>\r\n  <ion-toolbar>\r\n    <ion-title>Login</ion-title>\r\n  </ion-toolbar>\r\n</ion-header>\r\n\r\n<ion-content>\r\n  <ion-grid>\r\n    <ion-row class=\"ion-align-items-center ion-justify-content-center\">\r\n      <ion-col size-md=\"8\" size-sm>\r\n        <ion-card>\r\n          <ion-card-header>\r\n            <ion-segment (ionChange)=\"tabChanged($event)\" [value]=\"tab\">\r\n              <ion-segment-button value=\"device\" id=\"login-device\">\r\n                <ion-label>Login dengan kode perangkat</ion-label>\r\n              </ion-segment-button>\r\n              <ion-segment-button value=\"provider\" id=\"login-provider\">\r\n                <ion-label>Login dengan kode faskes</ion-label>\r\n              </ion-segment-button>\r\n            </ion-segment>\r\n          </ion-card-header>\r\n\r\n          <ion-card-content>\r\n            <ng-container *ngIf=\"tab === 'device'\">\r\n              <form\r\n                ngForm\r\n                #loginDeviceForm=\"ngForm\"\r\n                (ngSubmit)=\"loginDevice(loginDeviceForm)\"\r\n              >\r\n                <ion-list lines=\"full\" class=\"ion-no-margin ion-no-padding\">\r\n                  <ion-item>\r\n                    <ion-label position=\"floating\">\r\n                      kode perangkat\r\n                      <ion-text\r\n                        color=\"danger\"\r\n                        *ngIf=\"device_id.invalid && (device_id.dirty || device_id.touched)\"\r\n                      >\r\n                        <span *ngIf=\"device_id?.errors?.required\">\r\n                          wajib diisi\r\n                        </span>\r\n                      </ion-text>\r\n                    </ion-label>\r\n                    <ion-input\r\n                      name=\"device_id\"\r\n                      [(ngModel)]=\"deviceID\"\r\n                      type=\"text\"\r\n                      placeholder=\"misal prkt123\"\r\n                      required\r\n                      #device_id=\"ngModel\"\r\n                      id=\"device-id\"\r\n                    ></ion-input>\r\n                  </ion-item>\r\n                </ion-list>\r\n                <div class=\"ion-padding\">\r\n                  <ion-button\r\n                    type=\"submit\"\r\n                    shape=\"round\"\r\n                    expand=\"block\"\r\n                    color=\"primary\"\r\n                    (click)=\"loginDevice(loginDeviceForm)\"\r\n                    [disabled]=\"!loginDeviceForm.form.valid\"\r\n                    id=\"submit-device\"\r\n                  >\r\n                    <ion-icon slot=\"start\" name=\"unlock\"></ion-icon>\r\n                    Login\r\n                  </ion-button>\r\n                </div>\r\n              </form>\r\n            </ng-container>\r\n\r\n            <ng-container *ngIf=\"tab === 'provider'\">\r\n              <form ngForm #loginProviderForm=\"ngForm\">\r\n                <ion-list lines=\"full\" class=\"ion-no-margin ion-no-padding\">\r\n                  <ion-item>\r\n                    <ion-label position=\"floating\">\r\n                      kode faskes\r\n                      <ion-text\r\n                        color=\"danger\"\r\n                        *ngIf=\"provider_id.invalid && (provider_id.dirty || provider_id.touched)\"\r\n                      >\r\n                        <span *ngIf=\"provider_id?.errors?.required\">\r\n                          wajib diisi\r\n                        </span>\r\n                      </ion-text>\r\n                    </ion-label>\r\n                    <ion-input\r\n                      name=\"provider_id\"\r\n                      [(ngModel)]=\"providerID\"\r\n                      type=\"text\"\r\n                      placeholder=\"misal klinik_sehat\"\r\n                      required\r\n                      #provider_id=\"ngModel\"\r\n                      id=\"provider-code\"\r\n                    ></ion-input>\r\n                  </ion-item>\r\n\r\n                  <ion-item>\r\n                    <ion-label position=\"floating\">\r\n                      password\r\n                      <ion-text\r\n                        color=\"danger\"\r\n                        *ngIf=\"passwords.invalid && (passwords.dirty || passwords.touched)\"\r\n                      >\r\n                        <span *ngIf=\"passwords?.errors?.required\">\r\n                          wajib diisi\r\n                        </span>\r\n                      </ion-text>\r\n                    </ion-label>\r\n                    <ion-input\r\n                      name=\"password\"\r\n                      [(ngModel)]=\"password\"\r\n                      type=\"password\"\r\n                      required\r\n                      #passwords=\"ngModel\"\r\n                      id=\"provider-password\"\r\n                    ></ion-input>\r\n                  </ion-item>\r\n                </ion-list>\r\n\r\n                <div class=\"ion-padding\">\r\n                  <ion-button\r\n                    shape=\"round\"\r\n                    expand=\"block\"\r\n                    color=\"primary\"\r\n                    (click)=\"loginProvider()\"\r\n                    [disabled]=\"!loginProviderForm.form.valid\"\r\n                    id=\"submit-provider\"\r\n                  >\r\n                    <ion-icon slot=\"start\" name=\"unlock\"></ion-icon>\r\n                    Login\r\n                  </ion-button>\r\n                </div>\r\n              </form>\r\n            </ng-container>\r\n          </ion-card-content>\r\n        </ion-card>\r\n      </ion-col>\r\n    </ion-row>\r\n  </ion-grid>\r\n</ion-content>\r\n"
            }] }
];
/** @nocollapse */
LoginPage.ctorParameters = () => [
    { type: ToastController },
    { type: LoadingController },
    { type: Router },
    { type: EdgeCentralClient }
];
if (false) {
    /** @type {?} */
    LoginPage.prototype.tab;
    /** @type {?} */
    LoginPage.prototype.deviceID;
    /** @type {?} */
    LoginPage.prototype.providerID;
    /** @type {?} */
    LoginPage.prototype.password;
    /**
     * @type {?}
     * @private
     */
    LoginPage.prototype.toast;
    /**
     * @type {?}
     * @private
     */
    LoginPage.prototype.loading;
    /**
     * @type {?}
     * @private
     */
    LoginPage.prototype.router;
    /**
     * @type {?}
     * @private
     */
    LoginPage.prototype.ec;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ec-login.router.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const routes = [{ path: '', component: LoginPage }];
/**
 * Login Router modules
 * @export
 */
class EdgeCentralLoginRoutingModule {
}
EdgeCentralLoginRoutingModule.decorators = [
    { type: NgModule, args: [{
                imports: [RouterModule.forChild(routes)],
                exports: [RouterModule],
                declarations: []
            },] }
];
/** @type {?} */
const routedComponents = [LoginPage];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/ec-login.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Module to provide context user interface before accessing edge central features
 *
 * @export
 */
class EdgeCentralLoginModule {
}
EdgeCentralLoginModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    IonicModule,
                    CommonModule,
                    EdgeCentralLoginRoutingModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: [...routedComponents]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: sirusdev-ec-client-angular-login.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { EdgeCentralLoginModule, EdgeCentralLoginRoutingModule as ɵa, routedComponents as ɵb, LoginPage as ɵc };
//# sourceMappingURL=sirusdev-ec-client-angular-login.js.map
