import { ApolloClient } from 'apollo-client';
export interface ECLite {
    fetch: (input: RequestInfo, init: any) => Promise<Response>;
    WebSocket: WebSocket;
}
declare global {
    interface Window {
        eclite: ECLite;
    }
}
export declare class EdgeCentralConfig {
    cloudCentralHost: string;
    edgeCN: string;
    ecvcHost: string;
    inSecureEC?: boolean;
    inSecureCC?: boolean;
    mocked?: boolean;
}
export interface EdgeCentralClientConfig {
    apiUrl: string;
    subscriptionUrl: string;
    token: string;
}
export declare const DEVICE_TOKEN = "--ec-on-device-token--";
export declare class EdgeCentralClient {
    private config;
    private store;
    client: ApolloClient<any>;
    private ecHttpProtocol;
    private ecWsProtocol;
    private ccHttpProtocol;
    constructor(config: EdgeCentralConfig);
    isAuthenticated(): Promise<boolean>;
    /**
     * return true when chrome inject script from ec-lite extenstion are presents
     */
    isUsingChromeExtension(): boolean;
    loadApolloClient(): Promise<void>;
    createApolloClient(): Promise<ApolloClient<any>>;
    setClientConfig(config: EdgeCentralClientConfig): Promise<EdgeCentralClientConfig>;
    getClientConfig(): Promise<EdgeCentralClientConfig>;
    /**
     * logout and clear client contexts
     */
    logout(): Promise<void>;
    loginByProvider(providerId: string, password: string): Promise<void>;
    loginByDevice(deviceId: string): Promise<void>;
}
